<?php

/**
  * SquirrelMail Startup Folder Plugin
  * Copyright (C) 2003 Scott Heavner <sdh@po.cwru.edu>
  * Copyright (C) 2004 Paul Lesneiwski <pdontthink@angrynerds.com>
  * This program is licensed under GPL. See COPYING for details
  *
  */


function squirrelmail_plugin_init_startup_folder() {

  global $squirrelmail_plugin_hooks;

  $squirrelmail_plugin_hooks['webmail_top']['startup_folder'] =
    'startup_folder_override_';
  $squirrelmail_plugin_hooks['optpage_loadhook_folder']['startup_folder'] =
    'startup_folder_options_';
}

function startup_folder_version() {
  return '2.0';
}

if (!defined('SM_PATH'))
   define('SM_PATH', '../');

function startup_folder_override_() {
  include_once(SM_PATH . 'plugins/startup_folder/functions.php');
  startup_folder_override();
}

function startup_folder_options_() {
  include_once(SM_PATH . 'plugins/startup_folder/functions.php');
  startup_folder_options();
}

?>
